@@ -338,7 +338,7 @@ enum { WRITE_CURRENT_STATES, CHANGE_STATES_TO_DEFAULT };
 // for the buttons inside the "new xy" mask
 enum { CANCEL_NEW_XY, RESET_NEW_XY, OK_NEW_XY };
 // for push_new_item_on_undo_stack ()
-enum { NOT_AFTER_SAVE, AFTER_SAVE };
+enum { NOT_AFTER_SAVE_UNDER_NEW_FILE_NAME, AFTER_SAVE_UNDER_NEW_FILE_NAME };
 // for create_dialog ()
 enum { DONT_SHOW_IMMEDIATELY, SHOW_IMMEDIATELY };
 // for iterations through the tree
@@ -352,7 +352,7 @@ enum { CONTINUE_ITERATING, STOP_ITERATING };
 */
 
 
-#define KICKSHAW_VERSION "1.1.193"
+#define KICKSHAW_VERSION "1.1.194"
 #define RELEASED_IN "2025"
 
 #define TREEVIEW_COLUMN_OFFSET NUMBER_OF_TS_ELEMENTS - NUMBER_OF_COLUMNS
