@@ -703,7 +703,9 @@ void save_menu (gchar *save_as_filename)
         */
         free_elements_of_static_string_array (save_txts_toplevel, NUMBER_OF_TXT_FIELDS, FALSE);
         free_elements_of_static_string_array (save_menu_args.save_txts, NUMBER_OF_TXT_FIELDS, FALSE);
-        g_object_unref (save_menu_args.filter_model);
+        if (save_menu_args.filter_model) {
+            g_object_unref (save_menu_args.filter_model);
+        }
 
         return;
     }
@@ -941,8 +943,8 @@ void save_menu (gchar *save_as_filename)
     ks.change_done = FALSE;
 
     if (G_UNLIKELY (!(STREQ (filename_prior_to_saving, ks.filename)))) {
-        // Replace the current undo stack item with a new one that contains the new file name.
-        push_new_item_on_undo_stack (AFTER_SAVE);
+        // Replace the current undo stack item with one that includes the new file name.
+        push_new_item_on_undo_stack (AFTER_SAVE_UNDER_NEW_FILE_NAME);
     }
     // Change sensitivity of save button and remove additional save button tooltip texts, if they were shown.
     row_selected ();
